This function create the mesh for modelling with INLA framework
fm_mesh(x, k, loc, plot = NULL)
Arguments
- x
is the sf object and the target variable.
- k
is the parameter for defining the delaunay triagulization.
- loc
is the locality (sf).
- plot
is a logical argument. if TRUE plot the mesh else no plot the mesh.
Value
a mesh and plot of the mesh.